# -*- coding: utf-8 -*-
# noqa: D100
#
# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))


# -- Project information -----------------------------------------------------

project = 'MRToolsTheme'
copyright = '2020—2022, Michael Rippstein'
author = 'Michael Rippstein'

try:
    from importlib.metadata import version  # noqa:E402
except ModuleNotFoundError:
    from importlib_metadata import version  # noqa:E402

release = version('mrtoolstheme')
# for example take major/minor
version = '.'.join(release.split('.')[:2])

# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.viewcode',
    'sphinx.ext.doctest',
    'sphinx.ext.intersphinx',
    'sphinx.ext.todo',
    'sphinx.ext.napoleon',
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']

# If true, sectionauthor and moduleauthor directives will be shown in the
# output. They are ignored by default.
show_authors = True

numfig = True
numfig_format = {
    'figure': 'Figure %s',
    'table': 'Table %s',
    'code-block': 'Listing %s',
    'section': 'Section %s',
}

# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'mrtools'

html_theme_options = {
    'logo': 'logo_toolstheme.png',
    'document_h_font_color': 'var(--nord11)',
}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

# -- Extension configuration -------------------------------------------------

# -- Options for intersphinx extension ---------------------------------------

# Example configuration for intersphinx: refer to the Python standard library.
intersphinx_mapping = {
    'python': ('https://docs.python.org/3', None),
}

# -- Options for todo extension ----------------------------------------------

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = True

# -- Options for Napoleon extension ------------------------------------------
napoleon_google_docstring = False
napoleon_numpy_docstring = True
napoleon_include_init_with_doc = False
napoleon_include_private_with_doc = True
napoleon_include_special_with_doc = True
napoleon_use_admonition_for_examples = False
napoleon_use_admonition_for_notes = False
napoleon_use_admonition_for_references = False
napoleon_use_ivar = False
napoleon_use_param = True
napoleon_use_keyword = True
napoleon_use_rtype = True
napoleon_preprocess_types = False
napoleon_type_aliases = None
napoleon_attr_annotations = True

# -- Options for autodoc extension -------------------------------------------
autodoc_default_options = {
    'member-order': 'groupwise',
    'exclude-members': '__weakref__, __module__, __doc__, __dict__',
    'show-inheritance': True,
}

autodoc_member_order = 'bysource'



"""Register the Sphinx HTML Theme `mrtools`.

.. moduleauthor:: Michael Rippstein <info@anatas.ch>

:copyright: Copyright 2022 by Michael Rippstein.
:license: AGPL, see LICENSE for details.
"""

from os import path


def setup(app):
    """Register the Sphinx HTML Theme `mrtools`."""
    app.add_html_theme('mrtools', path.abspath(path.dirname(__file__)))



# -*- coding: utf-8 -*-

"""
Setuptools setup for the module :mod:`mrtoolstheme`.

.. moduleauthor:: Michael Rippstein <info@anatas.ch>

:copyright: Copyright 2022 by Michael Rippstein.
:license: AGPL, see LICENSE for details.
"""

from setuptools import setup

setup()



# -*- coding: utf-8 -*-
"""Pygments Style: mrtools.

.. moduleauthor:: Michael Rippstein <michael@anatas.ch>

:copyright: Copyright 2022 by Michael Rippstein.
:license: AGPL, see LICENSE for details.
"""

from pygments.style import Style
from pygments.token import (
    Keyword,
    Name,
    Comment,
    String,
    Error,
    Number,
    Operator,
    Generic,
    Whitespace,
    Punctuation,
    Other,
    Literal,
)

NORD_COLORS = {
    # Polar Night
    'night00': '#2e3440',
    'night01': '#3d4454',
    'night02': '#4b5569',
    'night03': '#5a667d',
    # Snow Storm
    'storm00': '#b0bac5',
    'storm01': '#d3d9e3',
    'storm02': '#dde2eb',
    'storm03': '#e6ebf2',
    # Frost
    'frost00': '#8fbcbb',
    'frost01': '#88c0d0',
    'frost02': '#81a1c1',
    'frost03': '#5e81ac',
    # Aurora
    'aurora1': '#bf616a',  # red
    'aurora2': '#d08770',  # orange
    'aurora3': '#ebcb8b',  # yellow
    'aurora4': '#a3be8c',  # green
    'aurora5': '#b48ead',  # violette
}


class MrToolsStyle(Style):    # pylint: disable=too-few-public-methods
    """Pygments Style for the Sphinx Theme `mrtools`."""

    # work in progress...

    colors = NORD_COLORS

    background_color = colors['night01']
    highlight_color = colors['night03']
    default_style = colors['night03']

    styles = {
        # No corresponding class for the following:
        # Text:                 "", # class:  ''
        Whitespace: '',  # "underline " + colors['storm03'],       # class: 'w'
        Error: colors['aurora1'] + ' border:' + colors['aurora2'],  # class: 'err'
        Other: colors['storm03'],  # class 'x'
        Comment: 'italic ' + colors['storm00'],  # class: 'c'
        Comment.Multiline: 'italic ' + colors['storm00'],  # class: 'cm'
        Comment.Preproc: 'italic ' + colors['storm00'],  # class: 'cp'
        Comment.Single: 'italic ' + colors['storm00'],  # class: 'c1'
        Comment.Special: 'italic ' + colors['storm00'],  # class: 'cs'
        Keyword: 'bold ' + colors['frost00'],  # class: 'k'
        Keyword.Constant: 'bold ' + colors['frost00'],  # class: 'kc'
        Keyword.Declaration: 'bold ' + colors['frost00'],  # class: 'kd'
        Keyword.Namespace: 'bold ' + colors['frost00'],  # class: 'kn'
        Keyword.Pseudo: 'bold ' + colors['frost00'],  # class: 'kp'
        Keyword.Reserved: 'bold ' + colors['frost00'],  # class: 'kr'
        Keyword.Type: 'bold ' + colors['frost00'],  # class: 'kt'
        Operator: 'bold ' + colors['frost00'],  # class: 'o'
        Operator.Word: 'bold ' + colors['frost00'],  # class: 'ow'
        Punctuation: 'bold ' + colors['storm03'],  # class: 'p'
        # because special names such as Name.Class, Name.Function, etc.
        # are not recognized as such later in the parsing, we choose them
        # to look the same as ordinary variables.
        Name: colors['storm03'],  # class: 'n'
        Name.Attribute: colors['storm03'],  # class: 'na'
        Name.Builtin: colors['aurora2'],  # class: 'nb'
        Name.Builtin.Pseudo: colors['aurora2'],  # class: 'bp'
        Name.Class: colors['storm03'],  # class: 'nc'
        Name.Constant: colors['storm03'],  # class: 'no'
        Name.Decorator: 'bold ' + colors['storm01'],  # class: 'nd'
        Name.Entity: colors['storm03'],  # class: 'ni'
        Name.Exception: 'bold ' + colors['aurora1'],  # class: 'ne'
        Name.Function: colors['storm03'],  # class: 'nf'
        Name.Property: colors['storm03'],  # class: 'py'
        Name.Label: colors['storm03'],  # class: 'nl'
        Name.Namespace: colors['storm03'],  # class: 'nn'
        Name.Other: colors['storm03'],  # class: 'nx'
        Name.Tag: colors['storm03'],  # class: 'nt'
        Name.Variable: colors['storm03'],  # class: 'nv'
        Name.Variable.Class: colors['storm03'],  # class: 'vc'
        Name.Variable.Global: colors['storm03'],  # class: 'vg'
        Name.Variable.Instance: colors['storm03'],  # class: 'vi'
        Number: colors['storm03'],  # class: 'm'
        Number.Float: colors['storm03'],  # class: 'mf'
        Number.Hex: colors['storm03'],  # class: 'mh'
        Number.Integer: colors['storm03'],  # class: 'mi'
        Number.Integer.Long: colors['storm03'],  # class: 'il'
        Number.Oct: colors['storm03'],  # class: 'mo'
        Literal: colors['storm03'],  # class: 'l'
        Literal.Date: colors['storm03'],  # class: 'ld'
        String: colors['aurora4'],  # class: 's'
        String.Backtick: colors['aurora4'],  # class: 'sb'
        String.Char: colors['aurora4'],  # class: 'sc'
        String.Doc: 'italic ' + colors['frost02'],  # class: 'sd'
        String.Double: colors['aurora4'],  # class: 's2'
        String.Escape: colors['aurora4'],  # class: 'se'
        String.Heredoc: colors['aurora4'],  # class: 'sh'
        String.Interpol: colors['aurora4'],  # class: 'si'
        String.Other: colors['aurora4'],  # class: 'sx'
        String.Regex: colors['aurora4'],  # class: 'sr'
        String.Single: colors['aurora4'],  # class: 's1'
        String.Symbol: colors['aurora4'],  # class: 'ss'
        Generic: colors['storm03'],  # class: 'g'
        Generic.Deleted: colors['night02'],  # class: 'gd'
        Generic.Emph: 'italic ' + colors['storm03'],  # class: 'ge'
        Generic.Error: colors['aurora1'],  # class: 'gr'
        Generic.Heading: 'bold ' + colors['storm03'],  # class: 'gh'
        Generic.Inserted: colors['storm03'],  # class: 'gi'
        Generic.Output: 'italic ' + colors['storm03'],  # class: 'go'
        Generic.Prompt: colors['storm03'],  # class: 'gp'
        Generic.Strong: 'bold ' + colors['storm03'],  # class: 'gs'
        Generic.Subheading: 'bold ' + colors['storm03'],  # class: 'gu'
        Generic.Traceback: 'bold ' + colors['storm01'],  # class: 'gt'
    }
